@@ -172,6 +172,19 @@ class ErrorCodes(object):
         PhoneFormatIsInvalid = "92202"
         UrlFormatIsInvalid = "92206"
 
+    class Dispute(object):
+        CanOnlyAddEvidenceToOpenDispute = "95701"
+        CanOnlyRemoveEvidenceFromOpenDispute = "95702"
+        CanOnlyAddEvidenceDocumentToDispute = "95703"
+        CanOnlyAcceptOpenDispute = "95704"
+        CanOnlyFinalizeOpenDispute = "95705"
+
+    class DocumentUpload(object):
+        KindIsInvalid = "84901"
+        FileIsTooLarge = "84902"
+        FileTypeIsInvalid = "84903"
+        FileIsMalformedOrEncrypted = "84904"
+
     class Merchant(object):
         CountryCannotBeBlank = "83603"
         CountryCodeAlpha2IsInvalid = "93607"
@@ -322,6 +335,7 @@ class ErrorCodes(object):
         PaymentMethodNonceConsumed = "93107"
         PaymentMethodNonceUnknown = "93108"
         PaymentMethodNonceLocked = "93109"
+        PaymentMethodNoLongerSupported = "93117"
         AuthExpired = "92911"
         CannotHaveFundingSourceWithoutAccessToken = "92912"
         InvalidFundingSourceSelection = "92913"
@@ -430,6 +444,7 @@ class ErrorCodes(object):
     class Transaction(object):
         AmountCannotBeNegative = "81501"
         AmountDoesNotMatch3DSecureAmount = "91585"
+        AmountDoesNotMatchIdealPaymentAmount = "915144"
         AmountIsInvalid = AmountFormatIsInvalid = "81503"
         AmountIsRequired = "81502"
         AmountIsTooLarge = "81528"
@@ -463,14 +478,31 @@ class ErrorCodes(object):
         CustomerDefaultPaymentMethodCardTypeIsNotAccepted = "81509"
         CustomerDoesNotHaveCreditCard = "91511"
         CustomerIdIsInvalid = "91510"
+        FailedAuthAdjustmentAllowRetry = "95603"
+        FailedAuthAdjustmentHardDecline = "95602"
+        FinalAuthSubmitForSettlementForDifferentAmount = "95601"
         HasAlreadyBeenRefunded = "91512"
+        IdealPaymentNotComplete = "815141"
+        IdealPaymentsCannotBeVaulted = "915150"
+        DiscountAmountFormatIsInvalid = "915159"
+        DiscountAmountCannotBeNegative = "915160"
+        DiscountAmountIsTooLarge = "915161"
+        ShippingAmountFormatIsInvalid = "915162"
+        ShippingAmountCannotBeNegative = "915163"
+        ShippingAmountIsTooLarge = "915164"
+        ShipsFromPostalCodeIsTooLong = "915165"
+        ShipsFromPostalCodeIsInvalid = "915166"
+        ShipsFromPostalCodeInvalidCharacters = "915167"
         MerchantAccountDoesNotMatch3DSecureMerchantAccount = "91584"
+        MerchantAccountDoesNotMatchIdealPaymentMerchantAccount = "915143"
         MerchantAccountDoesNotSupportMOTO = "91558"
         MerchantAccountDoesNotSupportRefunds = "91547"
         MerchantAccountIdIsInvalid = "91513"
         MerchantAccountIsSusped = "91514" # Deprecated
         MerchantAccountIsSuspended = "91514"
         MerchantAccountNameIsInvalid = "91513" # Deprecated
+        OrderIdDoesNotMatchIdealPaymentOrderId = "91503"
+        OrderIdIsRequiredWithIdealPayment = "91502"
         OrderIdIsTooLong = "91501"
         PayPalAuthExpired = "91579"
         PayPalNotEnabled = "91576"
@@ -524,6 +556,8 @@ class ErrorCodes(object):
         ThreeDSecureXidIsRequired = "915115"
         ThreeDSecureEciFlagIsInvalid = "915114"
         ThreeDSecureMerchantAccountDoesNotSupportCardType = "915131"
+        TooManyLineItems = "915157"
+        LineItemsExpected = "915158"
         TypeIsInvalid = "91523"
         TypeIsRequired = "91524"
         UnsupportedVoiceAuthorization = "91539"
@@ -538,7 +572,7 @@ class ErrorCodes(object):
                 CustomFieldTooLong = "91580"
 
         class Industry(object):
-            IndustryTypeIsInvalid = "93401" 
+            IndustryTypeIsInvalid = "93401"
 
             class Lodging(object):
                 EmptyData = "93402"
@@ -554,3 +588,35 @@ class ErrorCodes(object):
                 DepartureDateIsInvalid = "93411"
                 LodgingCheckInDateIsInvalid = "93412"
                 LodgingCheckOutDateIsInvalid = "93413"
+
+        class LineItem(object):
+            CommodityCodeIsTooLong = "95801"
+            DescriptionIsTooLong = "95803"
+            DiscountAmountFormatIsInvalid = "95804"
+            DiscountAmountIsTooLarge = "95805"
+            DiscountAmountMustBeGreaterThanZero = "95806" # Deprecated as the amount may be zero.
+            DiscountAmountCannotBeNegative = "95806"
+            KindIsInvalid = "95807"
+            KindIsRequired = "95808"
+            NameIsRequired = "95822"
+            NameIsTooLong = "95823"
+            ProductCodeIsTooLong = "95809"
+            QuantityFormatIsInvalid = "95810"
+            QuantityIsRequired = "95811"
+            QuantityIsTooLarge = "95812"
+            TotalAmountFormatIsInvalid = "95813"
+            TotalAmountIsRequired = "95814"
+            TotalAmountIsTooLarge = "95815"
+            TotalAmountMustBeGreaterThanZero = "95816"
+            UnitAmountFormatIsInvalid = "95817"
+            UnitAmountIsRequired = "95818"
+            UnitAmountIsTooLarge = "95819"
+            UnitAmountMustBeGreaterThanZero = "95820"
+            UnitOfMeasureIsTooLarge = "95821"
+            UnitTaxAmountFormatIsInvalid = "95824"
+            UnitTaxAmountIsTooLarge = "95825"
+            UnitTaxAmountMustBeGreaterThanZero = "95826" # Deprecated as the amount may be zero.
+            UnitTaxAmountCannotBeNegative = "95826"
+            TaxAmountFormatIsInvalid = "95827"
+            TaxAmountIsTooLarge = "95828"
+            TaxAmountCannotBeNegative = "95829"
